@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,15 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import grpc_helpers_async  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
+import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
@@ -30,8 +28,7 @@ from grpc.experimental import aio  # type: ignore
 from google.cloud.scheduler_v1.types import cloudscheduler
 from google.cloud.scheduler_v1.types import job
 from google.cloud.scheduler_v1.types import job as gcs_job
-from google.protobuf import empty_pb2 as empty  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 from .base import CloudSchedulerTransport, DEFAULT_CLIENT_INFO
 from .grpc import CloudSchedulerGrpcTransport
 
@@ -57,7 +54,7 @@ class CloudSchedulerGrpcAsyncIOTransport(CloudSchedulerTransport):
     def create_channel(
         cls,
         host: str = "cloudscheduler.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -84,13 +81,15 @@ class CloudSchedulerGrpcAsyncIOTransport(CloudSchedulerTransport):
         Returns:
             aio.Channel: A gRPC AsyncIO channel object.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
         return grpc_helpers_async.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            default_scopes=cls.AUTH_SCOPES,
+            scopes=scopes,
+            default_host=cls.DEFAULT_HOST,
             **kwargs,
         )
 
@@ -98,7 +97,7 @@ class CloudSchedulerGrpcAsyncIOTransport(CloudSchedulerTransport):
         self,
         *,
         host: str = "cloudscheduler.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         channel: aio.Channel = None,
@@ -108,11 +107,13 @@ class CloudSchedulerGrpcAsyncIOTransport(CloudSchedulerTransport):
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id=None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
     ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -148,6 +149,8 @@ class CloudSchedulerGrpcAsyncIOTransport(CloudSchedulerTransport):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
 
         Raises:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
@@ -170,7 +173,6 @@ class CloudSchedulerGrpcAsyncIOTransport(CloudSchedulerTransport):
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
             self._ssl_channel_credentials = None
-
         else:
             if api_mtls_endpoint:
                 host = api_mtls_endpoint
@@ -200,6 +202,7 @@ class CloudSchedulerGrpcAsyncIOTransport(CloudSchedulerTransport):
             scopes=scopes,
             quota_project_id=quota_project_id,
             client_info=client_info,
+            always_use_jwt_access=always_use_jwt_access,
         )
 
         if not self._grpc_channel:
@@ -347,7 +350,7 @@ class CloudSchedulerGrpcAsyncIOTransport(CloudSchedulerTransport):
     @property
     def delete_job(
         self,
-    ) -> Callable[[cloudscheduler.DeleteJobRequest], Awaitable[empty.Empty]]:
+    ) -> Callable[[cloudscheduler.DeleteJobRequest], Awaitable[empty_pb2.Empty]]:
         r"""Return a callable for the delete job method over gRPC.
 
         Deletes a job.
@@ -366,7 +369,7 @@ class CloudSchedulerGrpcAsyncIOTransport(CloudSchedulerTransport):
             self._stubs["delete_job"] = self.grpc_channel.unary_unary(
                 "/google.cloud.scheduler.v1.CloudScheduler/DeleteJob",
                 request_serializer=cloudscheduler.DeleteJobRequest.serialize,
-                response_deserializer=empty.Empty.FromString,
+                response_deserializer=empty_pb2.Empty.FromString,
             )
         return self._stubs["delete_job"]
 
