@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,48 +13,48 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
-from .target import (
-    HttpTarget,
-    AppEngineHttpTarget,
-    PubsubTarget,
-    AppEngineRouting,
-    OAuthToken,
-    OidcToken,
+from .cloudscheduler import (
+    CreateJobRequest,
+    DeleteJobRequest,
+    GetJobRequest,
+    ListJobsRequest,
+    ListJobsResponse,
+    PauseJobRequest,
+    ResumeJobRequest,
+    RunJobRequest,
+    UpdateJobRequest,
 )
 from .job import (
     Job,
     RetryConfig,
 )
-from .cloudscheduler import (
-    ListJobsRequest,
-    ListJobsResponse,
-    GetJobRequest,
-    CreateJobRequest,
-    UpdateJobRequest,
-    DeleteJobRequest,
-    PauseJobRequest,
-    ResumeJobRequest,
-    RunJobRequest,
+from .target import (
+    AppEngineHttpTarget,
+    AppEngineRouting,
+    HttpTarget,
+    OAuthToken,
+    OidcToken,
+    PubsubTarget,
+    HttpMethod,
 )
 
-
 __all__ = (
-    "HttpTarget",
-    "AppEngineHttpTarget",
-    "PubsubTarget",
-    "AppEngineRouting",
-    "OAuthToken",
-    "OidcToken",
-    "Job",
-    "RetryConfig",
+    "CreateJobRequest",
+    "DeleteJobRequest",
+    "GetJobRequest",
     "ListJobsRequest",
     "ListJobsResponse",
-    "GetJobRequest",
-    "CreateJobRequest",
-    "UpdateJobRequest",
-    "DeleteJobRequest",
     "PauseJobRequest",
     "ResumeJobRequest",
     "RunJobRequest",
+    "UpdateJobRequest",
+    "Job",
+    "RetryConfig",
+    "AppEngineHttpTarget",
+    "AppEngineRouting",
+    "HttpTarget",
+    "OAuthToken",
+    "OidcToken",
+    "PubsubTarget",
+    "HttpMethod",
 )
