@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -37,11 +35,10 @@ from google.cloud.scheduler_v1beta1.types import cloudscheduler
 from google.cloud.scheduler_v1beta1.types import job
 from google.cloud.scheduler_v1beta1.types import job as gcs_job
 from google.cloud.scheduler_v1beta1.types import target
-from google.protobuf import duration_pb2 as duration  # type: ignore
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-from google.rpc import status_pb2 as status  # type: ignore
-
+from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+from google.rpc import status_pb2  # type: ignore
 from .transports.base import CloudSchedulerTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import CloudSchedulerGrpcTransport
 from .transports.grpc_asyncio import CloudSchedulerGrpcAsyncIOTransport
@@ -62,7 +59,7 @@ class CloudSchedulerClientMeta(type):
     _transport_registry["grpc_asyncio"] = CloudSchedulerGrpcAsyncIOTransport
 
     def get_transport_class(cls, label: str = None,) -> Type[CloudSchedulerTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -87,7 +84,8 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -121,7 +119,8 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -138,7 +137,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -157,23 +156,24 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
     @property
     def transport(self) -> CloudSchedulerTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            CloudSchedulerTransport: The transport used by the client instance.
+            CloudSchedulerTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def job_path(project: str, location: str, job: str,) -> str:
-        """Return a fully-qualified job string."""
+        """Returns a fully-qualified job string."""
         return "projects/{project}/locations/{location}/jobs/{job}".format(
             project=project, location=location, job=job,
         )
 
     @staticmethod
     def parse_job_path(path: str) -> Dict[str, str]:
-        """Parse a job path into its component segments."""
+        """Parses a job path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/jobs/(?P<job>.+?)$",
             path,
@@ -182,18 +182,18 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
     @staticmethod
     def topic_path(project: str, topic: str,) -> str:
-        """Return a fully-qualified topic string."""
+        """Returns a fully-qualified topic string."""
         return "projects/{project}/topics/{topic}".format(project=project, topic=topic,)
 
     @staticmethod
     def parse_topic_path(path: str) -> Dict[str, str]:
-        """Parse a topic path into its component segments."""
+        """Parses a topic path into its component segments."""
         m = re.match(r"^projects/(?P<project>.+?)/topics/(?P<topic>.+?)$", path)
         return m.groupdict() if m else {}
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -206,7 +206,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -217,7 +217,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -228,7 +228,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -239,7 +239,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -253,12 +253,12 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, CloudSchedulerTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the cloud scheduler client.
+        """Instantiates the cloud scheduler client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -313,9 +313,10 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -327,12 +328,14 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -347,8 +350,8 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -386,7 +389,6 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -418,10 +420,8 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudscheduler.ListJobsRequest):
             request = cloudscheduler.ListJobsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -469,7 +469,6 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -499,10 +498,8 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudscheduler.GetJobRequest):
             request = cloudscheduler.GetJobRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -559,7 +556,6 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 This corresponds to the ``job`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -589,10 +585,8 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudscheduler.CreateJobRequest):
             request = cloudscheduler.CreateJobRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if job is not None:
@@ -619,7 +613,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         request: cloudscheduler.UpdateJobRequest = None,
         *,
         job: gcs_job.Job = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -660,7 +654,6 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -690,10 +683,8 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudscheduler.UpdateJobRequest):
             request = cloudscheduler.UpdateJobRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if job is not None:
                 request.job = job
             if update_mask is not None:
@@ -738,7 +729,6 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -761,10 +751,8 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudscheduler.DeleteJobRequest):
             request = cloudscheduler.DeleteJobRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -816,7 +804,6 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -846,10 +833,8 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudscheduler.PauseJobRequest):
             request = cloudscheduler.PauseJobRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -901,7 +886,6 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -931,10 +915,8 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudscheduler.ResumeJobRequest):
             request = cloudscheduler.ResumeJobRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -979,7 +961,6 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1009,10 +990,8 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudscheduler.RunJobRequest):
             request = cloudscheduler.RunJobRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
