@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,14 +13,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Callable, Dict, Optional, Sequence, Tuple
+from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import grpc_helpers  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+import google.auth  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
@@ -29,8 +27,7 @@ import grpc  # type: ignore
 from google.cloud.scheduler_v1beta1.types import cloudscheduler
 from google.cloud.scheduler_v1beta1.types import job
 from google.cloud.scheduler_v1beta1.types import job as gcs_job
-from google.protobuf import empty_pb2 as empty  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 from .base import CloudSchedulerTransport, DEFAULT_CLIENT_INFO
 
 
@@ -54,7 +51,7 @@ class CloudSchedulerGrpcTransport(CloudSchedulerTransport):
         self,
         *,
         host: str = "cloudscheduler.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         channel: grpc.Channel = None,
@@ -64,11 +61,13 @@ class CloudSchedulerGrpcTransport(CloudSchedulerTransport):
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
     ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -103,6 +102,8 @@ class CloudSchedulerGrpcTransport(CloudSchedulerTransport):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
 
         Raises:
           google.auth.exceptions.MutualTLSChannelError: If mutual TLS transport
@@ -155,6 +156,7 @@ class CloudSchedulerGrpcTransport(CloudSchedulerTransport):
             scopes=scopes,
             quota_project_id=quota_project_id,
             client_info=client_info,
+            always_use_jwt_access=always_use_jwt_access,
         )
 
         if not self._grpc_channel:
@@ -178,7 +180,7 @@ class CloudSchedulerGrpcTransport(CloudSchedulerTransport):
     def create_channel(
         cls,
         host: str = "cloudscheduler.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -209,13 +211,15 @@ class CloudSchedulerGrpcTransport(CloudSchedulerTransport):
             google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
         return grpc_helpers.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            default_scopes=cls.AUTH_SCOPES,
+            scopes=scopes,
+            default_host=cls.DEFAULT_HOST,
             **kwargs,
         )
 
@@ -335,7 +339,9 @@ class CloudSchedulerGrpcTransport(CloudSchedulerTransport):
         return self._stubs["update_job"]
 
     @property
-    def delete_job(self) -> Callable[[cloudscheduler.DeleteJobRequest], empty.Empty]:
+    def delete_job(
+        self,
+    ) -> Callable[[cloudscheduler.DeleteJobRequest], empty_pb2.Empty]:
         r"""Return a callable for the delete job method over gRPC.
 
         Deletes a job.
@@ -354,7 +360,7 @@ class CloudSchedulerGrpcTransport(CloudSchedulerTransport):
             self._stubs["delete_job"] = self.grpc_channel.unary_unary(
                 "/google.cloud.scheduler.v1beta1.CloudScheduler/DeleteJob",
                 request_serializer=cloudscheduler.DeleteJobRequest.serialize,
-                response_deserializer=empty.Empty.FromString,
+                response_deserializer=empty_pb2.Empty.FromString,
             )
         return self._stubs["delete_job"]
 
